@@ -4,14 +4,13 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 use base 'Text::Pipe::Base';
 
     
-__PACKAGE__
-    ->mk_array_accessors(qw(pipes));
+__PACKAGE__->mk_array_accessors(qw(pipes));
 
 
 {
